Servers
-------

.. autoclass:: socketio.Server
   :members:
   :inherited-members:

.. autoclass:: socketio.AsyncServer
   :members:
   :inherited-members:

.. autoclass:: socketio.exceptions.ConnectionRefusedError
   :members:

